pub struct Benchmark { /* private fields */ }
Simple benchmark or a stage

Implementations

source

impl Benchmark

source

pub fn new0() -> Self

Create simple benchmark with unknown number of iterations

source

pub fn new(iterations: u32) -> Self

Create simple benchmark with pre-defined number of iterations

source

pub fn reset(&mut self)

Reset the benchmark timer

source

pub fn finish0(&mut self)

Finish a simple benchmark

source

pub fn finish(&mut self, iterations: Option<u32>, errors: Option<u32>)

Finish a simple benchmark, specifying number of iterations made

source

pub fn print0(&self)

Print a simple benchmark result

source

pub fn print(&self, iterations: Option<u32>, errors: Option<u32>)

Print a simple benchmark result, specifying number of iterations made

source

pub fn result0(&self) -> BenchmarkResult

Get a benchmark result

source

pub fn result( &self, iterations: Option<u32>, errors: Option<u32> ) -> BenchmarkResult

Get a benchmark result, specifying number of iterations made

source

pub fn increment(&mut self)

Increment iterations inside benchmark

Not required to use if the number of iterations is specified at benchmark creation or finish / print

source

pub fn increment_errors(&mut self)

Increment errors inside benchmark

Not required to use if the number of errors is specified at benchmark finish / print