Struct bma_benchmark::BenchmarkResult [−][src]
Benchmark results for a simple benchmark or a stage
Fields
elapsed: Durationiterations: u32speed: u32Benchmark results for a simple benchmark or a stage
elapsed: Durationiterations: u32speed: u32