Struct bma_benchmark::StageBenchmark[][src]

pub struct StageBenchmark { /* fields omitted */ }
Stage benchmark

Implementations

Start benchmark stage

Panics

Will panic if a stage with the same name already exists

Finish benchmark stage

Panics

Will panic if a specified stage was not started

Finish current (last started) benchmark stage

Reset staged benchmark

Get the result table for staged benchmark

Get the result table for staged benchmark, specifying the reference stage

Print the result table

Print the result table, specifying the reference stage