pub struct StagedBenchmark { /* private fields */ }
Staged benchmark

Implementations

source

impl StagedBenchmark

source

pub fn new() -> Self

source

pub fn start(&mut self, name: &str)

Start benchmark stage

Panics

Will panic if a stage with the same name already exists

source

pub fn finish(&mut self, name: &str, iterations: u32, errors: u32)

Finish benchmark stage

Panics

Will panic if a specified stage was not started

source

pub fn finish_current(&mut self, iterations: u32, errors: u32)

Finish current (last started) benchmark stage

source

pub fn reset(&mut self)

Reset staged benchmark

source

pub fn result_table(&self) -> Table

Get the result table for staged benchmark

source

pub fn result_table_for(&self, eta: &str) -> Table

Get the result table for staged benchmark, specifying the reference stage

source

pub fn print(&self)

Print the result table

source

pub fn print_for(&self, eta: &str)

Print the result table, specifying the reference stage