Struct bma_benchmark::Benchmark [−][src]
pub struct Benchmark { /* fields omitted */ }Expand description
Simple benchmark or a stage
Implementations
Create simple benchmark with pre-defined number of iterations
Finish a simple benchmark, specifying number of iterations made
Print a simple benchmark result, specifying number of iterations made
Get a benchmark result
Get a benchmark result, specifying number of iterations made
Increment iterations inside benchmark
Not required to use if the number of iterations is specified at benchmark creation or finish / print
Increment errors inside benchmark
Not required to use if the number of errors is specified at benchmark finish / print