Struct bma_benchmark::Benchmark[][src]

pub struct Benchmark { /* fields omitted */ }
Simple benchmark or a stage

Implementations

Create simple benchmark with unknown number of iterations

Create simple benchmark with pre-defined number of iterations

Reset the benchmark timer

Finish a simple benchmark

Finish a simple benchmark, specifying number of iterations made

Print a simple benchmark result

Print a simple benchmark result, specifying number of iterations made

Get a benchmark result

Get a benchmark result, specifying number of iterations made

Increment iterations inside benchmark

Not required to use if the number of iterations is specified at benchmark creation or finish / print