pub struct Benchmark { /* fields omitted */ }
Simple benchmark or a stage
Create simple benchmark with unknown number of iterations
Create simple benchmark with pre-defined number of iterations
Reset the benchmark timer
Finish a simple benchmark
Finish a simple benchmark, specifying number of iterations made
Print a simple benchmark result
Print a simple benchmark result, specifying number of iterations made
Get a benchmark result, specifying number of iterations made
Increment iterations inside benchmark
Not required to use if the number of iterations is specified at benchmark creation or
finish / print
Returns the “default value” for a type. Read more
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.