pub struct StageBenchmark { /* fields omitted */ }
Start benchmark stage
Will panic if a stage with the same name already exists
Finish benchmark stage
Will panic if a specified stage was not started
Finish current (last started) benchmark stage
Get the result table for staged benchmark
Get the result table for staged benchmark, specifying the reference stage
Print the result table, specifying the reference stage
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.